Check for identifiability of fixed effects
check_estimability.RdCalculates the matrix of second-derivatives of the marginal likelihood with respect to fixed effects, to see if any linear combinations are not estimable (i.e. cannot be uniquely estimated conditional upon model structure and available data, e.g., resulting in a likelihood ridge and singular, non-invertable Hessian matrix)