Run a grid
run_grid.RdFit a model for each grid cell defined in grid where each grid cell has a
different combination of fixed parameter values.
Arguments
- data
a
listcontaining the data created using theget_datafunction.- grid_parameters
a
listof parameter inputs for each grid cell. This can be created usingget_grid.- bounds
the lower and upper parameter bounds created using the
get_boundsfunction.- map
a
listdefining how to optionally collect and fix parameters.- random
a character
vectordefining the random effect parameters.- control
a
listdefining the controls passed tonlminb.