Plot spawning biomass
plot_biomass_spawning.RdPlot the spawning biomass (tonnes) or relative spawning biomass by year for a single model run, a grid of model runs, or an MCMC.
Usage
plot_biomass_spawning(
data_list,
object_list,
posterior = NULL,
probs = c(0.025, 0.975),
relative = TRUE,
labels = NULL
)Arguments
- data_list
a
listcontaining the data that was passed toMakeADFun.- object_list
a
listspecifying the AD object created using theMakeADFunfunction.- posterior
an
rstanobjected created using thetmbstanfunction.- probs
a numeric vector of probabilities with values in
[0,1]for plotting quantiles of the posterior distribution. Defaults to the 90% credible interval.- relative
if the plot should be relative spawning biomass.
- labels
a
vectorof labels for the model runs.