Run a grid again
rerun_grid.RdFit a model for each grid cell defined in grid where each grid cell has a
different combination of fixed parameter values.
Usage
rerun_grid(grid, bounds, control = list(eval.max = 10000, iter.max = 10000))
rerun_grid.RdFit a model for each grid cell defined in grid where each grid cell has a
different combination of fixed parameter values.
rerun_grid(grid, bounds, control = list(eval.max = 10000, iter.max = 10000))